# binder

This folder contains config files to setup the docker image on 
[mybinder.org](https://mybinder.org/).

`requirements.txt`
: requirements to run pychemcurv on binder

`postBuild`
: post build commands to enable jupyter extension